commit 35a0f4ed602228fa76ce1a8a1c9b764c8b27a582
Author: Leszek Koltunski <leszek@koltunski.pl>
Date:   Sat Apr 24 00:37:53 2021 +0200

    Calibration of the previous workaround.

diff --git a/src/main/res/raw/blit_depth_fragment_shader.glsl b/src/main/res/raw/blit_depth_fragment_shader.glsl
index 6c1eb40..2c52b12 100644
--- a/src/main/res/raw/blit_depth_fragment_shader.glsl
+++ b/src/main/res/raw/blit_depth_fragment_shader.glsl
@@ -26,14 +26,15 @@ uniform sampler2D u_Texture;
 uniform sampler2D u_DepthTexture;
 
 //////////////////////////////////////////////////////////////////////////////////////////////
 // why -0.000001 ? On some drivers (for example Qualcomm's V@331, V@415 on Adreno 308 - also on
 // some Mali devices ) without it the depth test - when postprocessing a flat 2D object - does
 // not pass (for unknown reasons) and we don't see the Glow halo.  See for example the 'Glowing
 // Leaf' test app.
-// 0.000001 shouldn't hurt anyway.
+// Why exactly 0.0003? Testing of the Cube app on the SM-A315F. ( Mali G52, drivr r20p0 )
+// 0.0003 shouldn't hurt anyway.
 
 void main()                    		
   {
-  gl_FragDepth = texture(u_DepthTexture,v_TexCoordinate).r -0.000001;
+  gl_FragDepth = texture(u_DepthTexture,v_TexCoordinate).r -0.0003;
   fragColor    = texture(u_Texture     ,v_TexCoordinate);
   }
\ No newline at end of file
@@ -26,14 +26,15 @@ uniform sampler2D u_Texture;
 
 //////////////////////////////////////////////////////////////////////////////////////////////
-// why -0.000001 ? On some drivers (for example Qualcomm's V@331, V@415 on Adreno 308 - also on
+// why -0.0003 ? On some drivers (for example Qualcomm's V@331, V@415 on Adreno 308 - also on
 // some Mali devices ) without it the depth test - when postprocessing a flat 2D object - does
 // not pass (for unknown reasons) and we don't see the Glow halo.  See for example the 'Glowing
